@@ -10,7 +10,11 @@ negate_ <- function(e, ...){
     if (op == "!="){
       substitute( l == r, list(l = left(e), r = right(e)))
     } else if (op == "=="){
-      substitute( l != r, list(l = left(e), r = right(e)))
+      if (is.logical(right(e))){
+        substitute( l == r, list(l = left(e), r = !right(e)))
+      } else {
+        substitute( l != r, list(l = left(e), r = right(e)))
+      }
     }
     else {
       substitute( !(e), list(e=e) )
